import ostools.FileHandler as fh


# this is just a boiler plate script for the files injector.

# inject the strings.xml into the project_path + /app/src/main/res/values/strings.xml
def inject_strings(project_path, strings_file):
    project_strings_file = project_path + "/app/src/main/res/values"
    fh.copy_file(strings_file, project_strings_file)


# inject the google-services.json into project_path + /app/google-services.json
def inject_google_services(project_path, google_services_file):
    project_google_services_file = project_path + "/app/"
    fh.copy_file(google_services_file, project_google_services_file)


# inject the logo into project_path + /app/src/main/res/drawable/logo.png
def inject_logo(project_path, logo_file):
    project_logo_file = project_path + "/app/src/main/res/drawable"
    fh.copy_file(logo_file, project_logo_file)


def clear_old_assets(project_path):
    assets_dir = project_path + '/app/src/main/assets'
    if fh.is_dir_exists(assets_dir):
        fh.clear_dir_content(assets_dir)


# inject the assets into project_path + /app/src/main/assets
def inject_assets(project_path, asset_paths_list):
    project_assets_dir = project_path + "/app/src/main/assets"

    if not fh.is_dir_exists(project_assets_dir):
        fh.create_dir(project_assets_dir)

    fh.copy_list_of_files(asset_paths_list, project_assets_dir)



from distutils.core import setup

setup(
    name='os-android-files-injector',
    packages=['os_android_files_injector'],
    version='1.0',
    license='MIT',
    description='Will inject strings.xml, google-services.json, logo.png, assets and more files into an android app programmatically (dynamically)',
    author='Oz Shabat',
    author_email='osfunapps@gmail.com',
    url='https://github.com/osfunapps',
    keywords=['python', 'osfunapps', 'injector', 'android', 'files', 'strings', 'logo', 'assets'],
    install_requires=['ostools'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',  # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: MIT License',  # Again, pick a license

        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)



import ostools.LoggerHandler as lh
import os_android_files_injector.AppFilesInjectorBp as bp


##################################################################################
#
# this module meant to inject android app files into a designated android project.
#
##################################################################################

def run(project_path, strings_file=None, logo_file=None, google_services_file=None, asset_paths_list=None, clear_old_assets=False):
    """
    Will inject files into an android project.

    Args:
       project_path: your android's app path
       strings_file: the path to the new strings.xml file
       logo_file: the path to the new logo file
       google_services_file: the path to the new Firebase json file
       asset_paths_list: an array of all of the assets you want to inject to the app
       clear_old_assets: toggle to true to remove old assets from your project
    """

    logger = lh.Logger(__file__)

    # copy all of the stuff
    if strings_file is not None:
        bp.inject_strings(project_path, strings_file)
        logger.info('strings.xml injected')

    if google_services_file is not None:
        bp.inject_google_services(project_path, google_services_file)
        logger.info('google_services.json injected')

    if logo_file is not None:
        bp.inject_logo(project_path, logo_file)
        logger.info('logo injected')

    if clear_old_assets is True:
        bp.clear_old_assets(project_path)
        logger.info('old assets cleared')

    if asset_paths_list is not None:
        bp.inject_assets(project_path, asset_paths_list)
        logger.info('all ' + str(len(asset_paths_list)) + ' assets injected')
